@@ -28,6 +28,11 @@
 #include "girnode.h"
 #include "gitypelib-internal.h"
 
+#ifdef _MSC_VER
+#define strtoll _strtoi64
+#define strtoull _strtoui64
+#endif
+
 static gulong string_count = 0;
 static gulong unique_string_count = 0;
 static gulong string_size = 0;
@@ -228,7 +233,7 @@ _g_ir_node_free (GIrNode *node)
 	_g_ir_node_free ((GIrNode *)type->parameter_type1);
 	_g_ir_node_free ((GIrNode *)type->parameter_type2);
 
-	g_free (type->interface);
+	g_free (type->giinterface);
 	g_strfreev (type->errors);
 
       }
@@ -1244,7 +1249,7 @@ serialize_type (GIrTypelibBuild    *build,
       GIrNode *iface;
       gchar *name;
 
-      iface = find_entry_node (build, node->interface, NULL);
+      iface = find_entry_node (build, node->giinterface, NULL);
       if (iface)
         {
           if (iface->type == G_IR_NODE_XREF)
@@ -1253,8 +1258,8 @@ serialize_type (GIrTypelibBuild    *build,
         }
       else
 	{
-	  g_warning ("Interface for type reference %s not found", node->interface);
-	  name = node->interface;
+	  g_warning ("Interface for type reference %s not found", node->giinterface);
+	  name = node->giinterface;
 	}
 
       g_string_append_printf (str, "%s%s", name,
@@ -1483,7 +1488,7 @@ _g_ir_node_build_typelib (GIrNode         *node,
 		      iface->reserved = 0;
 		      iface->tag = type->tag;
 		      iface->reserved2 = 0;
-		      iface->interface = find_entry (build, type->interface);
+		      iface->interface = find_entry (build, type->giinterface);
 
 		    }
 		    break;
