@@ -26,6 +26,7 @@ import subprocess
 
 from .utils import get_libtool_command, extract_libtool_shlib
 
+
 # For .la files, the situation is easy.
 def _resolve_libtool(options, binary, libraries):
     shlibs = []
@@ -36,6 +37,7 @@ def _resolve_libtool(options, binary, libraries):
 
     return shlibs
 
+
 # Assume ldd output is something vaguely like
 #
 #  libpangoft2-1.0.so.0 => /usr/lib/libpangoft2-1.0.so.0 (0x006c1000)
@@ -51,6 +53,7 @@ def _ldd_library_pattern(library_name):
     return re.compile("(?<![A-Za-z0-9_-])(lib*%s[^A-Za-z0-9_-][^\s\(\)]*)"
                       % re.escape(library_name))
 
+
 # This is a what we do for non-la files. We assume that we are on an
 # ELF-like system where ldd exists and the soname extracted with ldd is
 # a filename that can be opened with dlopen().
@@ -68,7 +71,7 @@ def _resolve_non_libtool(options, binary, libraries):
     if not libraries:
         return []
 
-    if os.name == 'OpenBSD':
+    if platform.platform().startswith('OpenBSD'):
         # Hack for OpenBSD when using the ports' libtool which uses slightly
         # different directories to store the libraries in. So rewite binary.args[0]
         # by inserting '.libs/'.
@@ -118,6 +121,7 @@ def _resolve_non_libtool(options, binary, libraries):
 
     return shlibs
 
+
 # We want to resolve a set of library names (the <foo> of -l<foo>)
 # against a library to find the shared library name. The shared
 # library name is suppose to be what you pass to dlopen() (or
